/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q tySequence__4eQHGndY6XBYpFOH09apV8Q;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content tySequence__4eQHGndY6XBYpFOH09apV8Q_Content;
typedef struct tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA;
typedef struct tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA;
typedef struct tySequence__LqZapiAqCFeXPQZdoIAUew tySequence__LqZapiAqCFeXPQZdoIAUew;
typedef struct tySequence__LqZapiAqCFeXPQZdoIAUew_Content tySequence__LqZapiAqCFeXPQZdoIAUew_Content;
typedef struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA;
typedef struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tySequence__4eQHGndY6XBYpFOH09apV8Q {
  NI len; tySequence__4eQHGndY6XBYpFOH09apV8Q_Content* p;
};
struct tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw {
	NimStringV2 symKind;
	NimStringV2 symTypeKind;
	NimStringV2 name;
	NimStringV2 generics;
	NIM_BOOL isGroup;
	NIM_BOOL parametersProvided;
	tySequence__4eQHGndY6XBYpFOH09apV8Q parameters;
	NimStringV2 outType;
};
typedef NU8 tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w;
struct tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct tySequence__LqZapiAqCFeXPQZdoIAUew {
  NI len; tySequence__LqZapiAqCFeXPQZdoIAUew_Content* p;
};
struct tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA {
	tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w kind;
union{
	struct {
	NimStringV2 text;
} _kind_1;
	struct {
	NimStringV2 labelFmt;
} _kind_2;
	struct {
	NimStringV2 lineIndent;
} _kind_3;
	struct {
	NimStringV2 adType;
} _kind_4;
	struct {
	NI level;
} _kind_5;
	struct {
	NI order;
} _kind_6;
	struct {
	NI quotationDepth;
} _kind_7;
	struct {
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
} _kind_8;
	struct {
	NimStringV2 tooltip;
} _kind_9;
	struct {
	NI colCount;
} _kind_10;
	struct {
	NIM_BOOL endsHeader;
} _kind_11;
	struct {
	NI span;
} _kind_12;
};
	NimStringV2 anchor;
	tySequence__LqZapiAqCFeXPQZdoIAUew sons;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg {
	Exception Sup;
};
struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA {
	tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg Sup;
};
typedef NU8 tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw;
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
typedef NimStringV2 tyArray__wgmwCG2MY84OFtPmYaVG9bA[14];
typedef NimStringV2 tyArray__hFPV9bffMpPjoz9bsO9crekNg[7];
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content { NI cap; tyTuple__UV3llMMYFckfui8YMBuUZA data[SEQ_DECL_SIZE]; };
struct tySequence__LqZapiAqCFeXPQZdoIAUew_Content { NI cap; tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* data[SEQ_DECL_SIZE]; };
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZenvvars_u82)(tySequence__4eQHGndY6XBYpFOH09apV8Q dest_p0);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__4eQHGndY6XBYpFOH09apV8Q, eqdup___stdZenvvars_u88)(tySequence__4eQHGndY6XBYpFOH09apV8Q src_p0);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___packagesZdocutilsZrstast_u88)(tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e_p0, NCSTRING ename_p1, NCSTRING procname_p2, NCSTRING filename_p3, NI line_p4);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringV2 s_p0);
static N_INLINE(NIM_BOOL, contains__stdZenumutils_u51)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1);
static N_INLINE(NI, find__stdZenumutils_u56)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103)(NimStringV2 s_p0);
N_NIMCALL(NimStringV2, mnewString)(NI len_p0);
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimPrepareStrMutationImpl__system_u2430)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLengthStrV2)(NimStringV2* s_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZdochelpers_u247)(tySequence__4eQHGndY6XBYpFOH09apV8Q* x_p0, tyTuple__UV3llMMYFckfui8YMBuUZA y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___stdZprivateZospaths2_u309)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0, tyTuple__UV3llMMYFckfui8YMBuUZA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZprivateZospaths2_u306)(tyTuple__UV3llMMYFckfui8YMBuUZA dest_p0);
extern TNimTypeV2 NTIv2__S29bKZF4TUS33IR7ZXb7fFA_;
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_2 = { 31 | NIM_STRLIT_FLAG, "toLangSymbol: wrong input kind " };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_3 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_2};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_4 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_5 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_6 = { 1 | NIM_STRLIT_FLAG, " " };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_7 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_6};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_8 = { 1 | NIM_STRLIT_FLAG, "`" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_9 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_8};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_10 = { 1 | NIM_STRLIT_FLAG, "[" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_11 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_10};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_12 = { 1 | NIM_STRLIT_FLAG, "]" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_13 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_12};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_14 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_15 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_14};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_16 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_17 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_16};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_18 = { 1 | NIM_STRLIT_FLAG, "{" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_19 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_18};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_20 = { 1 | NIM_STRLIT_FLAG, "," };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_21 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_20};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_22 = { 1 | NIM_STRLIT_FLAG, ";" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_23 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_22};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_24 = { 1 | NIM_STRLIT_FLAG, "*" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_25 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_24};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_26 = { 1 | NIM_STRLIT_FLAG, ":" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_27 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_26};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_28 = { 27 | NIM_STRLIT_FLAG, "incorrect state inBeginning" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_29 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_31 = { 4 | NIM_STRLIT_FLAG, "enum" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_32 = { 6 | NIM_STRLIT_FLAG, "object" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_33 = { 5 | NIM_STRLIT_FLAG, "tuple" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_34 = { 4 | NIM_STRLIT_FLAG, "type" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_35 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_36 = { 32 | NIM_STRLIT_FLAG, "incorrect state beforeSymbolName" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_37 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_38 = { 31 | NIM_STRLIT_FLAG, "incorrect state afterSymbolName" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_39 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_40 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_41 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_42 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_8};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_43 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_8};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_44 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_45 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_46 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_47 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_48 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_49 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_50 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_51 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_52 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_53 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_54 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_55 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_56 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_57 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_58 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_59 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_60 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_61 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_62 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_63 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_64 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_65 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_66 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_67 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_68 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_69 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_70 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_71 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_72 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_73 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_74 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_75 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_76 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_77 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_78 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_79 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_80 = { 1 | NIM_STRLIT_FLAG, "}" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_81 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_80};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_82 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_83 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_84 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_85 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_86 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_87 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_88 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_89 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_90 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_91 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_92 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_93 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_94 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_24};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_95 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_96 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_97 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_98 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_99 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_100 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_101 = {1, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_26};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_102 = { 4 | NIM_STRLIT_FLAG, "proc" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_103 = { 4 | NIM_STRLIT_FLAG, "func" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_104 = { 5 | NIM_STRLIT_FLAG, "macro" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_105 = { 6 | NIM_STRLIT_FLAG, "method" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_106 = { 8 | NIM_STRLIT_FLAG, "iterator" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_107 = { 8 | NIM_STRLIT_FLAG, "template" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_108 = { 9 | NIM_STRLIT_FLAG, "converter" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_109 = { 5 | NIM_STRLIT_FLAG, "const" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_110 = { 3 | NIM_STRLIT_FLAG, "var" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_111 = { 6 | NIM_STRLIT_FLAG, "module" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_112 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_113 = { 3 | NIM_STRLIT_FLAG, "ref" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_114 = {3, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_113};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_115 = { 3 | NIM_STRLIT_FLAG, "ptr" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_116 = {3, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_115};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_117 = {3, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_110};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_118 = { 4 | NIM_STRLIT_FLAG, "ref." };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_119 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_118};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_120 = { 4 | NIM_STRLIT_FLAG, "ptr." };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_121 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_120};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_122 = {27, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_28};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_123 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_124 = {32, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_36};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_125 = {31, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_38};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_126 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_127 = {0, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_4};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__jCyLKAh8jREuI9bH39cG9bbVw_129 = { 22 | NIM_STRLIT_FLAG, "unknown symbol kind $1" };
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_130 = {22, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_129};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_131 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_102};
static const NimStringV2 TM__jCyLKAh8jREuI9bH39cG9bbVw_133 = {4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34};
static NIM_CONST tyArray__dyW7vpmfeTYw8kX3EXuaJA TM__jCyLKAh8jREuI9bH39cG9bbVw_30 = {{4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_31},
{6, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_32},
{5, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_33}}
;
N_LIB_PRIVATE NIM_CONST tyArray__wgmwCG2MY84OFtPmYaVG9bA NimDefs__packagesZdocutilsZdochelpers_u201 = {{4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_102},
{4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_103},
{5, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_104},
{6, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_105},
{8, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_106},
{8, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_107},
{9, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_108},
{5, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_109},
{4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_34},
{3, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_110},
{4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_31},
{6, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_32},
{5, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_33},
{6, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_111}}
;
static NIM_CONST tyArray__hFPV9bffMpPjoz9bsO9crekNg TM__jCyLKAh8jREuI9bH39cG9bbVw_128 = {{4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_102},
{4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_103},
{5, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_104},
{6, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_105},
{8, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_106},
{8, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_107},
{9, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_108}}
;
static NIM_CONST tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ TM__jCyLKAh8jREuI9bH39cG9bbVw_132 = {{4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_102},
{4, (NimStrPayload*)&TM__jCyLKAh8jREuI9bH39cG9bbVw_103}}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZdochelpers_u159)(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).outType);
	eqdestroy___stdZenvvars_u82((*dest_p0).parameters);
	eqdestroy___system_u2691((*dest_p0).generics);
	eqdestroy___system_u2691((*dest_p0).name);
	eqdestroy___system_u2691((*dest_p0).symTypeKind);
	eqdestroy___system_u2691((*dest_p0).symKind);
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdup___packagesZdocutilsZdochelpers_u165)(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* src_p0, tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* Result) {
	nimZeroMem((void*)Result, sizeof(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw));
	(*Result).symKind = eqdup___system_u2697((*src_p0).symKind);
	(*Result).symTypeKind = eqdup___system_u2697((*src_p0).symTypeKind);
	(*Result).name = eqdup___system_u2697((*src_p0).name);
	(*Result).generics = eqdup___system_u2697((*src_p0).generics);
	(*Result).isGroup = (*src_p0).isGroup;
	(*Result).parametersProvided = (*src_p0).parametersProvided;
	(*Result).parameters = eqdup___stdZenvvars_u88((*src_p0).parameters);
	(*Result).outType = eqdup___system_u2697((*src_p0).outType);
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__stdZenumutils_u56)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1) {
	NI result;
{	result = ((NI)0);
	{
		NimStringV2* i_1;
		NI i_2;
		i_1 = (NimStringV2*)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < a_p0Len_0)) goto LA3;
				i_1 = (&a_p0[i_2]);
				{
					if (!eqStrings((*i_1), item_p1)) goto LA6_;
					goto BeforeRet_;
				}
LA6_: ;
				result += ((NI)1);
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	result = ((NI)-1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__stdZenumutils_u51)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1) {
	NIM_BOOL result;
	NI T1_;
{	T1_ = (NI)0;
	T1_ = find__stdZenumutils_u56(a_p0, a_p0Len_0, item_p1);
	result = (((NI)0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s_p0).p == ((NimStrPayload*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((NI)((*(*s_p0).p).cap & ((NI)1073741824)) == ((NI)1073741824));
LA4_: ;
		if (!T3_) goto LA5_;
		nimPrepareStrMutationImpl__system_u2430(s_p0);
	}
LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103)(NimStringV2 s_p0) {
	NimStringV2 result;
	NIM_BOOL firstChar_1;
	NI j_1;
	result.len = 0; result.p = NIM_NIL;
	result = mnewString((s_p0.len));
	firstChar_1 = NIM_TRUE;
	j_1 = ((NI)0);
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (NI)(s_p0.len - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA3;
				i_1 = ((NI) (res_1));
				{
					if (!(((NU8)(s_p0.p->data[i_1])) >= ((NU8)(65)) && ((NU8)(s_p0.p->data[i_1])) <= ((NU8)(90)))) goto LA6_;
					{
						if (!!(firstChar_1)) goto LA10_;
						nimPrepareStrMutationV2((&result));
						result.p->data[j_1] = ((NIM_CHAR) (((NI)(((NU8)(s_p0.p->data[i_1])) + ((NI)32)))));
					}
					goto LA8_;
LA10_: ;
					{
						nimPrepareStrMutationV2((&result));
						result.p->data[j_1] = s_p0.p->data[i_1];
						firstChar_1 = NIM_FALSE;
					}
LA8_: ;
					j_1 += ((NI)1);
				}
				goto LA4_;
LA6_: ;
				{
					if (!!((((NU8)(s_p0.p->data[i_1])) == ((NU8)(95)) || ((NU8)(s_p0.p->data[i_1])) == ((NU8)(32)) || ((NU8)(s_p0.p->data[i_1])) == ((NU8)(96))))) goto LA14_;
					nimPrepareStrMutationV2((&result));
					result.p->data[j_1] = s_p0.p->data[i_1];
					j_1 += ((NI)1);
					firstChar_1 = NIM_FALSE;
				}
				goto LA4_;
LA14_: ;
				{
					NIM_BOOL T17_;
					T17_ = (NIM_BOOL)0;
					T17_ = ((NU8)(s_p0.p->data[i_1]) == (NU8)(95));
					if (!(T17_)) goto LA18_;
					T17_ = firstChar_1;
LA18_: ;
					if (!T17_) goto LA19_;
					nimPrepareStrMutationV2((&result));
					result.p->data[j_1] = 95;
					j_1 += ((NI)1);
					firstChar_1 = NIM_FALSE;
				}
				goto LA4_;
LA19_: ;
				{
				}
LA4_: ;
				res_1 += ((NI)1);
			} LA3: ;
		}
	}
	{
		if (!!((j_1 == s_p0.len))) goto LA24_;
		setLengthStrV2((&result), (j_1));
	}
LA24_: ;
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, toLangSymbol__packagesZdocutilsZdochelpers_u188)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* linkText_p0, tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* Result) {
	NimStringV2 curIdent_1;
	tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw state_1;
	NI parens_1;
	NI L_1;
	NI T11_;
	NI i_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw));
	curIdent_1.len = 0; curIdent_1.p = NIM_NIL;
	{
		NimStringV2 colontmpD_;
		tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T7_;
		NimStringV2 T8_;
		if (!!(((*linkText_p0).kind == ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)43) || (*linkText_p0).kind == ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)0)))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T7_ = NIM_NIL;
		T7_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
		(*T7_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
		(*T7_).Sup.Sup.name = "ValueError";
		T8_.len = 0; T8_.p = NIM_NIL;
		colontmpD_ = dollar___packagesZdocutilsZrstast_u88((*linkText_p0).kind);
		T8_ = rawNewString(colontmpD_.len + 31);
appendString((&T8_), TM__jCyLKAh8jREuI9bH39cG9bbVw_3);
appendString((&T8_), colontmpD_);
		(*T7_).Sup.Sup.message = T8_;
		(*T7_).Sup.Sup.parent = ((Exception*) NIM_NIL);
		raiseExceptionEx((Exception*)T7_, "ValueError", "toLangSymbol", "dochelpers.nim", 101);
goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0);
	curIdent_1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_5;
	parens_1 = ((NI)0);
	T11_ = (*linkText_p0).sons.len;
	L_1 = T11_;
	i_1 = ((NI)0);
	{
		while (1) {
			if (!(i_1 < L_1)) goto LA13;
			switch (hashString((*(*linkText_p0).sons.p->data[i_1])._kind_1.text) & 15) {
			case 2: 
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_7)) goto LA14_;
break;
			case 3: 
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_13)) goto LA17_;
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_19)) goto LA20_;
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_27)) goto LA23_;
break;
			case 5: 
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_21)) goto LA21_;
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_25)) goto LA22_;
break;
			case 10: 
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_17)) goto LA19_;
break;
			case 13: 
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_11)) goto LA16_;
break;
			case 14: 
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_9)) goto LA15_;
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_15)) goto LA18_;
if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_23)) goto LA21_;
break;
			}
			goto LA24_;
			LA14_: ;
			{
				{
					if (!(state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1))) goto LA29_;
					{
						if (!!((curIdent_1.len == 0))) goto LA33_;
						switch (state_1) {
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T36_;
							T36_ = NIM_NIL;
							T36_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T36_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T36_).Sup.Sup.name = "ValueError";
							(*T36_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_29;
							(*T36_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T36_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
						{
							{
								NIM_BOOL T40_;
								T40_ = (NIM_BOOL)0;
								T40_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
								if (!T40_) goto LA41_;
								eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_35);
								eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
							goto LA38_;
LA41_: ;
							{
								eqsink___system_u2700((&(*Result).symKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
LA38_: ;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T45_;
							T45_ = NIM_NIL;
							T45_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T45_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T45_).Sup.Sup.name = "ValueError";
							(*T45_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_37;
							(*T45_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T45_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
						{
							NimStringV2 T47_;
							T47_.len = 0; T47_.p = NIM_NIL;
							T47_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T47_); goto LA1_;}
							eqsink___system_u2700((&(*Result).name), T47_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T49_;
							T49_ = NIM_NIL;
							T49_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T49_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T49_).Sup.Sup.name = "ValueError";
							(*T49_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_39;
							(*T49_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T49_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
						{
							eqsink___system_u2700((&(*Result).generics), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
						{
							tyTuple__UV3llMMYFckfui8YMBuUZA T52_;
							NimStringV2 blitTmp_1;
							blitTmp_1 = curIdent_1;
							eqwasMoved___system_u2688((&curIdent_1));
							T52_.Field0 = blitTmp_1;
							T52_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_40;
							add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T52_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
						{
							{
								NI aX60gensym19__1;
								NI colontmp_;
								NI T55_;
								NI res_1;
								aX60gensym19__1 = (NI)0;
								colontmp_ = (NI)0;
								T55_ = (*Result).parameters.len;
								colontmp_ = (NI)(T55_ - ((NI)1));
								res_1 = colontmp_;
								{
									while (1) {
										if (!(((NI)0) <= res_1)) goto LA57;
										aX60gensym19__1 = ((NI) (res_1));
										{
											if (!((*Result).parameters.p->data[aX60gensym19__1].Field1.len == 0)) goto LA60_;
											eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym19__1].Field1), curIdent_1);
										}
LA60_: ;
										res_1 -= ((NI)1);
									} LA57: ;
								}
							}
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
						{
							eqsink___system_u2700((&(*Result).outType), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						default: __builtin_unreachable();
						}
						eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_41);
					}
LA33_: ;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2);
				}
LA29_: ;
			}
			goto LA25_;
			LA15_: ;
			{
				NimStringV2 T70_;
				prepareAdd((&curIdent_1), 1);
appendString((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_42);
				i_1 += ((NI)1);
				{
					while (1) {
						if (!(i_1 < L_1)) goto LA65;
						prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
						{
							if (!eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_43)) goto LA68_;
							goto LA64;
						}
LA68_: ;
						i_1 += ((NI)1);
					} LA65: ;
				} LA64: ;
				T70_.len = 0; T70_.p = NIM_NIL;
				T70_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T70_); goto LA1_;}
				eqsink___system_u2700((&curIdent_1), T70_);
				{
					if (!(state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2))) goto LA73_;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3);
					{
						if (!!((curIdent_1.len == 0))) goto LA77_;
						switch (state_1) {
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T80_;
							T80_ = NIM_NIL;
							T80_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T80_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T80_).Sup.Sup.name = "ValueError";
							(*T80_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_44;
							(*T80_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T80_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
						{
							{
								NIM_BOOL T84_;
								T84_ = (NIM_BOOL)0;
								T84_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
								if (!T84_) goto LA85_;
								eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_45);
								eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
							goto LA82_;
LA85_: ;
							{
								eqsink___system_u2700((&(*Result).symKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
LA82_: ;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T89_;
							T89_ = NIM_NIL;
							T89_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T89_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T89_).Sup.Sup.name = "ValueError";
							(*T89_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_46;
							(*T89_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T89_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
						{
							NimStringV2 T91_;
							T91_.len = 0; T91_.p = NIM_NIL;
							T91_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T91_); goto LA1_;}
							eqsink___system_u2700((&(*Result).name), T91_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T93_;
							T93_ = NIM_NIL;
							T93_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T93_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T93_).Sup.Sup.name = "ValueError";
							(*T93_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_47;
							(*T93_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T93_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
						{
							eqsink___system_u2700((&(*Result).generics), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
						{
							tyTuple__UV3llMMYFckfui8YMBuUZA T96_;
							NimStringV2 blitTmp_2;
							blitTmp_2 = curIdent_1;
							eqwasMoved___system_u2688((&curIdent_1));
							T96_.Field0 = blitTmp_2;
							T96_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_48;
							add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T96_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
						{
							{
								NI aX60gensym32__1;
								NI colontmp__2;
								NI T99_;
								NI res_2;
								aX60gensym32__1 = (NI)0;
								colontmp__2 = (NI)0;
								T99_ = (*Result).parameters.len;
								colontmp__2 = (NI)(T99_ - ((NI)1));
								res_2 = colontmp__2;
								{
									while (1) {
										if (!(((NI)0) <= res_2)) goto LA101;
										aX60gensym32__1 = ((NI) (res_2));
										{
											if (!((*Result).parameters.p->data[aX60gensym32__1].Field1.len == 0)) goto LA104_;
											eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym32__1].Field1), curIdent_1);
										}
LA104_: ;
										res_2 -= ((NI)1);
									} LA101: ;
								}
							}
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
						{
							eqsink___system_u2700((&(*Result).outType), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						default: __builtin_unreachable();
						}
						eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_49);
					}
LA77_: ;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4);
				}
LA73_: ;
			}
			goto LA25_;
			LA16_: ;
			{
				{
					if (!!((state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2)))) goto LA110_;
					parens_1 += ((NI)1);
				}
LA110_: ;
				{
					if (!(state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2))) goto LA114_;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3);
					prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
				}
				goto LA112_;
LA114_: ;
				{
					NIM_BOOL T117_;
					T117_ = (NIM_BOOL)0;
					T117_ = (state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4));
					if (!(T117_)) goto LA118_;
					T117_ = (parens_1 == ((NI)1));
LA118_: ;
					if (!T117_) goto LA119_;
					{
						if (!!((curIdent_1.len == 0))) goto LA123_;
						switch (state_1) {
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T126_;
							T126_ = NIM_NIL;
							T126_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T126_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T126_).Sup.Sup.name = "ValueError";
							(*T126_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_50;
							(*T126_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T126_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
						{
							{
								NIM_BOOL T130_;
								T130_ = (NIM_BOOL)0;
								T130_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
								if (!T130_) goto LA131_;
								eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_51);
								eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
							goto LA128_;
LA131_: ;
							{
								eqsink___system_u2700((&(*Result).symKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
LA128_: ;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T135_;
							T135_ = NIM_NIL;
							T135_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T135_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T135_).Sup.Sup.name = "ValueError";
							(*T135_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_52;
							(*T135_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T135_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
						{
							NimStringV2 T137_;
							T137_.len = 0; T137_.p = NIM_NIL;
							T137_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T137_); goto LA1_;}
							eqsink___system_u2700((&(*Result).name), T137_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T139_;
							T139_ = NIM_NIL;
							T139_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T139_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T139_).Sup.Sup.name = "ValueError";
							(*T139_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_53;
							(*T139_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T139_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
						{
							eqsink___system_u2700((&(*Result).generics), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
						{
							tyTuple__UV3llMMYFckfui8YMBuUZA T142_;
							NimStringV2 blitTmp_3;
							blitTmp_3 = curIdent_1;
							eqwasMoved___system_u2688((&curIdent_1));
							T142_.Field0 = blitTmp_3;
							T142_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_54;
							add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T142_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
						{
							{
								NI aX60gensym46__1;
								NI colontmp__3;
								NI T145_;
								NI res_3;
								aX60gensym46__1 = (NI)0;
								colontmp__3 = (NI)0;
								T145_ = (*Result).parameters.len;
								colontmp__3 = (NI)(T145_ - ((NI)1));
								res_3 = colontmp__3;
								{
									while (1) {
										if (!(((NI)0) <= res_3)) goto LA147;
										aX60gensym46__1 = ((NI) (res_3));
										{
											if (!((*Result).parameters.p->data[aX60gensym46__1].Field1.len == 0)) goto LA150_;
											eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym46__1].Field1), curIdent_1);
										}
LA150_: ;
										res_3 -= ((NI)1);
									} LA147: ;
								}
							}
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
						{
							eqsink___system_u2700((&(*Result).outType), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						default: __builtin_unreachable();
						}
						eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_55);
					}
LA123_: ;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5);
					prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
				}
				goto LA112_;
LA119_: ;
				{
					prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
				}
LA112_: ;
			}
			goto LA25_;
			LA17_: ;
			{
				{
					if (!!((state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3)))) goto LA157_;
					parens_1 -= ((NI)1);
				}
LA157_: ;
				{
					NIM_BOOL T161_;
					T161_ = (NIM_BOOL)0;
					T161_ = (state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5));
					if (!(T161_)) goto LA162_;
					T161_ = (parens_1 == ((NI)0));
LA162_: ;
					if (!T161_) goto LA163_;
					prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
					{
						if (!!((curIdent_1.len == 0))) goto LA167_;
						switch (state_1) {
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T170_;
							T170_ = NIM_NIL;
							T170_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T170_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T170_).Sup.Sup.name = "ValueError";
							(*T170_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_56;
							(*T170_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T170_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
						{
							{
								NIM_BOOL T174_;
								T174_ = (NIM_BOOL)0;
								T174_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
								if (!T174_) goto LA175_;
								eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_57);
								eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
							goto LA172_;
LA175_: ;
							{
								eqsink___system_u2700((&(*Result).symKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
LA172_: ;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T179_;
							T179_ = NIM_NIL;
							T179_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T179_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T179_).Sup.Sup.name = "ValueError";
							(*T179_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_58;
							(*T179_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T179_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
						{
							NimStringV2 T181_;
							T181_.len = 0; T181_.p = NIM_NIL;
							T181_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T181_); goto LA1_;}
							eqsink___system_u2700((&(*Result).name), T181_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T183_;
							T183_ = NIM_NIL;
							T183_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T183_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T183_).Sup.Sup.name = "ValueError";
							(*T183_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_59;
							(*T183_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T183_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
						{
							eqsink___system_u2700((&(*Result).generics), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
						{
							tyTuple__UV3llMMYFckfui8YMBuUZA T186_;
							NimStringV2 blitTmp_4;
							blitTmp_4 = curIdent_1;
							eqwasMoved___system_u2688((&curIdent_1));
							T186_.Field0 = blitTmp_4;
							T186_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_60;
							add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T186_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
						{
							{
								NI aX60gensym60__1;
								NI colontmp__4;
								NI T189_;
								NI res_4;
								aX60gensym60__1 = (NI)0;
								colontmp__4 = (NI)0;
								T189_ = (*Result).parameters.len;
								colontmp__4 = (NI)(T189_ - ((NI)1));
								res_4 = colontmp__4;
								{
									while (1) {
										if (!(((NI)0) <= res_4)) goto LA191;
										aX60gensym60__1 = ((NI) (res_4));
										{
											if (!((*Result).parameters.p->data[aX60gensym60__1].Field1.len == 0)) goto LA194_;
											eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym60__1].Field1), curIdent_1);
										}
LA194_: ;
										res_4 -= ((NI)1);
									} LA191: ;
								}
							}
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
						{
							eqsink___system_u2700((&(*Result).outType), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						default: __builtin_unreachable();
						}
						eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_61);
					}
LA167_: ;
				}
				goto LA159_;
LA163_: ;
				{
					prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
				}
LA159_: ;
			}
			goto LA25_;
			LA18_: ;
			{
				parens_1 += ((NI)1);
				{
					if (!(state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2))) goto LA201_;
					(*Result).parametersProvided = NIM_TRUE;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3);
					{
						if (!!((curIdent_1.len == 0))) goto LA205_;
						switch (state_1) {
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T208_;
							T208_ = NIM_NIL;
							T208_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T208_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T208_).Sup.Sup.name = "ValueError";
							(*T208_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_62;
							(*T208_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T208_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
						{
							{
								NIM_BOOL T212_;
								T212_ = (NIM_BOOL)0;
								T212_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
								if (!T212_) goto LA213_;
								eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_63);
								eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
							goto LA210_;
LA213_: ;
							{
								eqsink___system_u2700((&(*Result).symKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
LA210_: ;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T217_;
							T217_ = NIM_NIL;
							T217_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T217_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T217_).Sup.Sup.name = "ValueError";
							(*T217_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_64;
							(*T217_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T217_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
						{
							NimStringV2 T219_;
							T219_.len = 0; T219_.p = NIM_NIL;
							T219_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T219_); goto LA1_;}
							eqsink___system_u2700((&(*Result).name), T219_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T221_;
							T221_ = NIM_NIL;
							T221_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T221_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T221_).Sup.Sup.name = "ValueError";
							(*T221_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_65;
							(*T221_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T221_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
						{
							eqsink___system_u2700((&(*Result).generics), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
						{
							tyTuple__UV3llMMYFckfui8YMBuUZA T224_;
							NimStringV2 blitTmp_5;
							blitTmp_5 = curIdent_1;
							eqwasMoved___system_u2688((&curIdent_1));
							T224_.Field0 = blitTmp_5;
							T224_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_66;
							add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T224_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
						{
							{
								NI aX60gensym72__1;
								NI colontmp__5;
								NI T227_;
								NI res_5;
								aX60gensym72__1 = (NI)0;
								colontmp__5 = (NI)0;
								T227_ = (*Result).parameters.len;
								colontmp__5 = (NI)(T227_ - ((NI)1));
								res_5 = colontmp__5;
								{
									while (1) {
										if (!(((NI)0) <= res_5)) goto LA229;
										aX60gensym72__1 = ((NI) (res_5));
										{
											if (!((*Result).parameters.p->data[aX60gensym72__1].Field1.len == 0)) goto LA232_;
											eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym72__1].Field1), curIdent_1);
										}
LA232_: ;
										res_5 -= ((NI)1);
									} LA229: ;
								}
							}
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
						{
							eqsink___system_u2700((&(*Result).outType), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						default: __builtin_unreachable();
						}
						eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_67);
					}
LA205_: ;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6);
				}
				goto LA199_;
LA201_: ;
				{
					NIM_BOOL T236_;
					T236_ = (NIM_BOOL)0;
					T236_ = (state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5));
					if (!(T236_)) goto LA237_;
					T236_ = (parens_1 == ((NI)1));
LA237_: ;
					if (!T236_) goto LA238_;
					(*Result).parametersProvided = NIM_TRUE;
					{
						if (!!((curIdent_1.len == 0))) goto LA242_;
						switch (state_1) {
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T245_;
							T245_ = NIM_NIL;
							T245_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T245_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T245_).Sup.Sup.name = "ValueError";
							(*T245_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_68;
							(*T245_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T245_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
						{
							{
								NIM_BOOL T249_;
								T249_ = (NIM_BOOL)0;
								T249_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
								if (!T249_) goto LA250_;
								eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_69);
								eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
							goto LA247_;
LA250_: ;
							{
								eqsink___system_u2700((&(*Result).symKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
LA247_: ;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T254_;
							T254_ = NIM_NIL;
							T254_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T254_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T254_).Sup.Sup.name = "ValueError";
							(*T254_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_70;
							(*T254_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T254_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
						{
							NimStringV2 T256_;
							T256_.len = 0; T256_.p = NIM_NIL;
							T256_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T256_); goto LA1_;}
							eqsink___system_u2700((&(*Result).name), T256_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T258_;
							T258_ = NIM_NIL;
							T258_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T258_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T258_).Sup.Sup.name = "ValueError";
							(*T258_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_71;
							(*T258_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T258_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
						{
							eqsink___system_u2700((&(*Result).generics), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
						{
							tyTuple__UV3llMMYFckfui8YMBuUZA T261_;
							NimStringV2 blitTmp_6;
							blitTmp_6 = curIdent_1;
							eqwasMoved___system_u2688((&curIdent_1));
							T261_.Field0 = blitTmp_6;
							T261_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_72;
							add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T261_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
						{
							{
								NI aX60gensym83__1;
								NI colontmp__6;
								NI T264_;
								NI res_6;
								aX60gensym83__1 = (NI)0;
								colontmp__6 = (NI)0;
								T264_ = (*Result).parameters.len;
								colontmp__6 = (NI)(T264_ - ((NI)1));
								res_6 = colontmp__6;
								{
									while (1) {
										if (!(((NI)0) <= res_6)) goto LA266;
										aX60gensym83__1 = ((NI) (res_6));
										{
											if (!((*Result).parameters.p->data[aX60gensym83__1].Field1.len == 0)) goto LA269_;
											eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym83__1].Field1), curIdent_1);
										}
LA269_: ;
										res_6 -= ((NI)1);
									} LA266: ;
								}
							}
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
						{
							eqsink___system_u2700((&(*Result).outType), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						default: __builtin_unreachable();
						}
						eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_73);
					}
LA242_: ;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6);
				}
				goto LA199_;
LA238_: ;
				{
					prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
				}
LA199_: ;
			}
			goto LA25_;
			LA19_: ;
			{
				parens_1 -= ((NI)1);
				{
					NIM_BOOL T276_;
					T276_ = (NIM_BOOL)0;
					T276_ = (state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7));
					if (!(T276_)) goto LA277_;
					T276_ = (parens_1 == ((NI)0));
LA277_: ;
					if (!T276_) goto LA278_;
					{
						if (!!((curIdent_1.len == 0))) goto LA282_;
						switch (state_1) {
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T285_;
							T285_ = NIM_NIL;
							T285_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T285_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T285_).Sup.Sup.name = "ValueError";
							(*T285_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_74;
							(*T285_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T285_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
						{
							{
								NIM_BOOL T289_;
								T289_ = (NIM_BOOL)0;
								T289_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
								if (!T289_) goto LA290_;
								eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_75);
								eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
							goto LA287_;
LA290_: ;
							{
								eqsink___system_u2700((&(*Result).symKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
LA287_: ;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T294_;
							T294_ = NIM_NIL;
							T294_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T294_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T294_).Sup.Sup.name = "ValueError";
							(*T294_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_76;
							(*T294_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T294_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
						{
							NimStringV2 T296_;
							T296_.len = 0; T296_.p = NIM_NIL;
							T296_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T296_); goto LA1_;}
							eqsink___system_u2700((&(*Result).name), T296_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T298_;
							T298_ = NIM_NIL;
							T298_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T298_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T298_).Sup.Sup.name = "ValueError";
							(*T298_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_77;
							(*T298_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T298_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
						{
							eqsink___system_u2700((&(*Result).generics), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
						{
							tyTuple__UV3llMMYFckfui8YMBuUZA T301_;
							NimStringV2 blitTmp_7;
							blitTmp_7 = curIdent_1;
							eqwasMoved___system_u2688((&curIdent_1));
							T301_.Field0 = blitTmp_7;
							T301_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_78;
							add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T301_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
						{
							{
								NI aX60gensym95__1;
								NI colontmp__7;
								NI T304_;
								NI res_7;
								aX60gensym95__1 = (NI)0;
								colontmp__7 = (NI)0;
								T304_ = (*Result).parameters.len;
								colontmp__7 = (NI)(T304_ - ((NI)1));
								res_7 = colontmp__7;
								{
									while (1) {
										if (!(((NI)0) <= res_7)) goto LA306;
										aX60gensym95__1 = ((NI) (res_7));
										{
											if (!((*Result).parameters.p->data[aX60gensym95__1].Field1.len == 0)) goto LA309_;
											eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym95__1].Field1), curIdent_1);
										}
LA309_: ;
										res_7 -= ((NI)1);
									} LA306: ;
								}
							}
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
						{
							eqsink___system_u2700((&(*Result).outType), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						default: __builtin_unreachable();
						}
						eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_79);
					}
LA282_: ;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8);
				}
				goto LA274_;
LA278_: ;
				{
					prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
				}
LA274_: ;
			}
			goto LA25_;
			LA20_: ;
			{
				{
					while (1) {
						if (!(i_1 < L_1)) goto LA315;
						{
							if (!eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_81)) goto LA318_;
							goto LA314;
						}
LA318_: ;
						i_1 += ((NI)1);
					} LA315: ;
				} LA314: ;
			}
			goto LA25_;
			LA21_: ;
			{
				{
					NIM_BOOL T323_;
					T323_ = (NIM_BOOL)0;
					T323_ = (state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6) || state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7));
					if (!(T323_)) goto LA324_;
					T323_ = (parens_1 == ((NI)1));
LA324_: ;
					if (!T323_) goto LA325_;
					{
						if (!!((curIdent_1.len == 0))) goto LA329_;
						switch (state_1) {
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T332_;
							T332_ = NIM_NIL;
							T332_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T332_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T332_).Sup.Sup.name = "ValueError";
							(*T332_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_82;
							(*T332_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T332_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
						{
							{
								NIM_BOOL T336_;
								T336_ = (NIM_BOOL)0;
								T336_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
								if (!T336_) goto LA337_;
								eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_83);
								eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
							goto LA334_;
LA337_: ;
							{
								eqsink___system_u2700((&(*Result).symKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
LA334_: ;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T341_;
							T341_ = NIM_NIL;
							T341_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T341_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T341_).Sup.Sup.name = "ValueError";
							(*T341_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_84;
							(*T341_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T341_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
						{
							NimStringV2 T343_;
							T343_.len = 0; T343_.p = NIM_NIL;
							T343_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T343_); goto LA1_;}
							eqsink___system_u2700((&(*Result).name), T343_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T345_;
							T345_ = NIM_NIL;
							T345_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T345_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T345_).Sup.Sup.name = "ValueError";
							(*T345_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_85;
							(*T345_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T345_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
						{
							eqsink___system_u2700((&(*Result).generics), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
						{
							tyTuple__UV3llMMYFckfui8YMBuUZA T348_;
							NimStringV2 blitTmp_8;
							blitTmp_8 = curIdent_1;
							eqwasMoved___system_u2688((&curIdent_1));
							T348_.Field0 = blitTmp_8;
							T348_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_86;
							add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T348_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
						{
							{
								NI aX60gensym108__1;
								NI colontmp__8;
								NI T351_;
								NI res_8;
								aX60gensym108__1 = (NI)0;
								colontmp__8 = (NI)0;
								T351_ = (*Result).parameters.len;
								colontmp__8 = (NI)(T351_ - ((NI)1));
								res_8 = colontmp__8;
								{
									while (1) {
										if (!(((NI)0) <= res_8)) goto LA353;
										aX60gensym108__1 = ((NI) (res_8));
										{
											if (!((*Result).parameters.p->data[aX60gensym108__1].Field1.len == 0)) goto LA356_;
											eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym108__1].Field1), curIdent_1);
										}
LA356_: ;
										res_8 -= ((NI)1);
									} LA353: ;
								}
							}
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
						{
							eqsink___system_u2700((&(*Result).outType), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						default: __builtin_unreachable();
						}
						eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_87);
					}
LA329_: ;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6);
				}
				goto LA321_;
LA325_: ;
				{
					prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
				}
LA321_: ;
			}
			goto LA25_;
			LA22_: ;
			{
				{
					if (!(state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3))) goto LA363_;
					{
						if (!!((curIdent_1.len == 0))) goto LA367_;
						switch (state_1) {
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T370_;
							T370_ = NIM_NIL;
							T370_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T370_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T370_).Sup.Sup.name = "ValueError";
							(*T370_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_88;
							(*T370_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T370_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
						{
							{
								NIM_BOOL T374_;
								T374_ = (NIM_BOOL)0;
								T374_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
								if (!T374_) goto LA375_;
								eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_89);
								eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
							goto LA372_;
LA375_: ;
							{
								eqsink___system_u2700((&(*Result).symKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
LA372_: ;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T379_;
							T379_ = NIM_NIL;
							T379_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T379_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T379_).Sup.Sup.name = "ValueError";
							(*T379_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_90;
							(*T379_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T379_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
						{
							NimStringV2 T381_;
							T381_.len = 0; T381_.p = NIM_NIL;
							T381_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T381_); goto LA1_;}
							eqsink___system_u2700((&(*Result).name), T381_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T383_;
							T383_ = NIM_NIL;
							T383_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T383_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T383_).Sup.Sup.name = "ValueError";
							(*T383_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_91;
							(*T383_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T383_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
						{
							eqsink___system_u2700((&(*Result).generics), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
						{
							tyTuple__UV3llMMYFckfui8YMBuUZA T386_;
							NimStringV2 blitTmp_9;
							blitTmp_9 = curIdent_1;
							eqwasMoved___system_u2688((&curIdent_1));
							T386_.Field0 = blitTmp_9;
							T386_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_92;
							add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T386_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
						{
							{
								NI aX60gensym119__1;
								NI colontmp__9;
								NI T389_;
								NI res_9;
								aX60gensym119__1 = (NI)0;
								colontmp__9 = (NI)0;
								T389_ = (*Result).parameters.len;
								colontmp__9 = (NI)(T389_ - ((NI)1));
								res_9 = colontmp__9;
								{
									while (1) {
										if (!(((NI)0) <= res_9)) goto LA391;
										aX60gensym119__1 = ((NI) (res_9));
										{
											if (!((*Result).parameters.p->data[aX60gensym119__1].Field1.len == 0)) goto LA394_;
											eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym119__1].Field1), curIdent_1);
										}
LA394_: ;
										res_9 -= ((NI)1);
									} LA391: ;
								}
							}
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
						{
							eqsink___system_u2700((&(*Result).outType), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						default: __builtin_unreachable();
						}
						eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_93);
					}
LA367_: ;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4);
				}
				goto LA361_;
LA363_: ;
				{
					if (!(state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4))) goto LA398_;
				}
				goto LA361_;
LA398_: ;
				{
					prepareAdd((&curIdent_1), 1);
appendString((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_94);
				}
LA361_: ;
			}
			goto LA25_;
			LA23_: ;
			{
				{
					if (!(state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8))) goto LA404_;
				}
				goto LA402_;
LA404_: ;
				{
					if (!(state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6))) goto LA407_;
					{
						if (!!((curIdent_1.len == 0))) goto LA411_;
						switch (state_1) {
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T414_;
							T414_ = NIM_NIL;
							T414_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T414_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T414_).Sup.Sup.name = "ValueError";
							(*T414_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_95;
							(*T414_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T414_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
						{
							{
								NIM_BOOL T418_;
								T418_ = (NIM_BOOL)0;
								T418_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
								if (!T418_) goto LA419_;
								eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_96);
								eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
							goto LA416_;
LA419_: ;
							{
								eqsink___system_u2700((&(*Result).symKind), curIdent_1);
								eqwasMoved___system_u2688((&curIdent_1));
							}
LA416_: ;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T423_;
							T423_ = NIM_NIL;
							T423_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T423_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T423_).Sup.Sup.name = "ValueError";
							(*T423_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_97;
							(*T423_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T423_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
						{
							NimStringV2 T425_;
							T425_.len = 0; T425_.p = NIM_NIL;
							T425_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T425_); goto LA1_;}
							eqsink___system_u2700((&(*Result).name), T425_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
						{
							tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T427_;
							T427_ = NIM_NIL;
							T427_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
							(*T427_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
							(*T427_).Sup.Sup.name = "ValueError";
							(*T427_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_98;
							(*T427_).Sup.Sup.parent = ((Exception*) NIM_NIL);
							raiseExceptionEx((Exception*)T427_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
						{
							eqsink___system_u2700((&(*Result).generics), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
						{
							tyTuple__UV3llMMYFckfui8YMBuUZA T430_;
							NimStringV2 blitTmp_10;
							blitTmp_10 = curIdent_1;
							eqwasMoved___system_u2688((&curIdent_1));
							T430_.Field0 = blitTmp_10;
							T430_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_99;
							add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T430_);
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
						{
							{
								NI aX60gensym129__1;
								NI colontmp__10;
								NI T433_;
								NI res_10;
								aX60gensym129__1 = (NI)0;
								colontmp__10 = (NI)0;
								T433_ = (*Result).parameters.len;
								colontmp__10 = (NI)(T433_ - ((NI)1));
								res_10 = colontmp__10;
								{
									while (1) {
										if (!(((NI)0) <= res_10)) goto LA435;
										aX60gensym129__1 = ((NI) (res_10));
										{
											if (!((*Result).parameters.p->data[aX60gensym129__1].Field1.len == 0)) goto LA438_;
											eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym129__1].Field1), curIdent_1);
										}
LA438_: ;
										res_10 -= ((NI)1);
									} LA435: ;
								}
							}
						}
						break;
						case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
						{
							eqsink___system_u2700((&(*Result).outType), curIdent_1);
							eqwasMoved___system_u2688((&curIdent_1));
						}
						break;
						default: __builtin_unreachable();
						}
						eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_100);
					}
LA411_: ;
					state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7);
				}
				goto LA402_;
LA407_: ;
				{
					prepareAdd((&curIdent_1), 1);
appendString((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_101);
				}
LA402_: ;
			}
			goto LA25_;
			LA24_: ;
			{
				NIM_BOOL isPostfixSymKindX60gensym17__1;
				NIM_BOOL T443_;
				NIM_BOOL T444_;
				NIM_BOOL T445_;
				T443_ = (NIM_BOOL)0;
				T444_ = (NIM_BOOL)0;
				T445_ = (NIM_BOOL)0;
				T445_ = (((NI)0) < i_1);
				if (!(T445_)) goto LA446_;
				T445_ = (i_1 == (NI)(L_1 - ((NI)1)));
LA446_: ;
				T444_ = T445_;
				if (!(T444_)) goto LA447_;
				T444_ = ((*Result).symKind.len == 0);
LA447_: ;
				T443_ = T444_;
				if (!(T443_)) goto LA448_;
				T443_ = contains__stdZenumutils_u51(NimDefs__packagesZdocutilsZdochelpers_u201, 14, (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
LA448_: ;
				isPostfixSymKindX60gensym17__1 = T443_;
				{
					if (!isPostfixSymKindX60gensym17__1) goto LA451_;
					{
						NIM_BOOL T455_;
						T455_ = (NIM_BOOL)0;
						T455_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
						if (!T455_) goto LA456_;
						eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_112);
						eqcopy___system_u2694((&(*Result).symTypeKind), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
					}
					goto LA453_;
LA456_: ;
					{
						eqcopy___system_u2694((&(*Result).symKind), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
					}
LA453_: ;
				}
				goto LA449_;
LA451_: ;
				{
					switch (state_1) {
					case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
					{
						{
							NIM_BOOL T463_;
							T463_ = (NIM_BOOL)0;
							T463_ = contains__stdZenumutils_u51(NimDefs__packagesZdocutilsZdochelpers_u201, 14, (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
							if (!T463_) goto LA464_;
							state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1);
						}
						goto LA461_;
LA464_: ;
						{
							state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3);
						}
LA461_: ;
						prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
					}
					break;
					case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
					case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
					{
						state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3);
						prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
					}
					break;
					case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
					{
						if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_114)) goto LA469_;
						if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_116)) goto LA470_;
						if (eqStrings((*(*linkText_p0).sons.p->data[i_1])._kind_1.text, TM__jCyLKAh8jREuI9bH39cG9bbVw_117)) goto LA471_;
						goto LA472_;
						LA469_: ;
						{
							prepareAdd((&curIdent_1), 4);
appendString((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_119);
						}
						goto LA473_;
						LA470_: ;
						{
							prepareAdd((&curIdent_1), 4);
appendString((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_121);
						}
						goto LA473_;
						LA471_: ;
						{
						}
						goto LA473_;
						LA472_: ;
						{
							NimStringV2 colontmpD__2;
							colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
							colontmpD__2 = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103((*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							prepareAdd((&curIdent_1), colontmpD__2.len + 0);
appendString((&curIdent_1), colontmpD__2);
							eqdestroy___system_u2691(colontmpD__2);
						}
LA473_: ;
					}
					break;
					case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
					{
						prepareAdd((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text.len + 0);
appendString((&curIdent_1), (*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
					}
					break;
					default:
					{
						NimStringV2 colontmpD__3;
						colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
						colontmpD__3 = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103((*(*linkText_p0).sons.p->data[i_1])._kind_1.text);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						prepareAdd((&curIdent_1), colontmpD__3.len + 0);
appendString((&curIdent_1), colontmpD__3);
						eqdestroy___system_u2691(colontmpD__3);
					}
					break;
					}
				}
LA449_: ;
			}
LA25_: ;
			i_1 += ((NI)1);
		} LA13: ;
	}
	{
		if (!(state_1 == ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1))) goto LA482_;
		state_1 = ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3);
	}
LA482_: ;
	{
		if (!!((curIdent_1.len == 0))) goto LA486_;
		switch (state_1) {
		case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)0):
		{
			tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T489_;
			T489_ = NIM_NIL;
			T489_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
			(*T489_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
			(*T489_).Sup.Sup.name = "ValueError";
			(*T489_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_122;
			(*T489_).Sup.Sup.parent = ((Exception*) NIM_NIL);
			raiseExceptionEx((Exception*)T489_, "ValueError", "toLangSymbol", "dochelpers.nim", 128);
goto LA1_;
		}
		break;
		case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)1):
		{
			{
				NIM_BOOL T493_;
				T493_ = (NIM_BOOL)0;
				T493_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_30, 3, curIdent_1);
				if (!T493_) goto LA494_;
				eqsink___system_u2700((&(*Result).symKind), TM__jCyLKAh8jREuI9bH39cG9bbVw_123);
				eqsink___system_u2700((&(*Result).symTypeKind), curIdent_1);
				eqwasMoved___system_u2688((&curIdent_1));
			}
			goto LA491_;
LA494_: ;
			{
				eqsink___system_u2700((&(*Result).symKind), curIdent_1);
				eqwasMoved___system_u2688((&curIdent_1));
			}
LA491_: ;
		}
		break;
		case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)2):
		{
			tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T498_;
			T498_ = NIM_NIL;
			T498_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
			(*T498_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
			(*T498_).Sup.Sup.name = "ValueError";
			(*T498_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_124;
			(*T498_).Sup.Sup.parent = ((Exception*) NIM_NIL);
			raiseExceptionEx((Exception*)T498_, "ValueError", "toLangSymbol", "dochelpers.nim", 130);
goto LA1_;
		}
		break;
		case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)3):
		{
			NimStringV2 T500_;
			T500_.len = 0; T500_.p = NIM_NIL;
			T500_ = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(curIdent_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T500_); goto LA1_;}
			eqsink___system_u2700((&(*Result).name), T500_);
		}
		break;
		case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)4):
		{
			tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T502_;
			T502_ = NIM_NIL;
			T502_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
			(*T502_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
			(*T502_).Sup.Sup.name = "ValueError";
			(*T502_).Sup.Sup.message = TM__jCyLKAh8jREuI9bH39cG9bbVw_125;
			(*T502_).Sup.Sup.parent = ((Exception*) NIM_NIL);
			raiseExceptionEx((Exception*)T502_, "ValueError", "toLangSymbol", "dochelpers.nim", 132);
goto LA1_;
		}
		break;
		case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)5):
		{
			eqsink___system_u2700((&(*Result).generics), curIdent_1);
			eqwasMoved___system_u2688((&curIdent_1));
		}
		break;
		case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)6):
		{
			tyTuple__UV3llMMYFckfui8YMBuUZA T505_;
			NimStringV2 blitTmp_11;
			blitTmp_11 = curIdent_1;
			eqwasMoved___system_u2688((&curIdent_1));
			T505_.Field0 = blitTmp_11;
			T505_.Field1 = TM__jCyLKAh8jREuI9bH39cG9bbVw_126;
			add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), T505_);
		}
		break;
		case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)7):
		{
			{
				NI aX60gensym153__1;
				NI colontmp__11;
				NI T508_;
				NI res_11;
				aX60gensym153__1 = (NI)0;
				colontmp__11 = (NI)0;
				T508_ = (*Result).parameters.len;
				colontmp__11 = (NI)(T508_ - ((NI)1));
				res_11 = colontmp__11;
				{
					while (1) {
						if (!(((NI)0) <= res_11)) goto LA510;
						aX60gensym153__1 = ((NI) (res_11));
						{
							if (!((*Result).parameters.p->data[aX60gensym153__1].Field1.len == 0)) goto LA513_;
							eqcopy___system_u2694((&(*Result).parameters.p->data[aX60gensym153__1].Field1), curIdent_1);
						}
LA513_: ;
						res_11 -= ((NI)1);
					} LA510: ;
				}
			}
		}
		break;
		case ((tyEnum_State__ONbNvmn7GfVrD4Ej3QrZUw)8):
		{
			eqsink___system_u2700((&(*Result).outType), curIdent_1);
			eqwasMoved___system_u2688((&curIdent_1));
		}
		break;
		default: __builtin_unreachable();
		}
		eqsink___system_u2700((&curIdent_1), TM__jCyLKAh8jREuI9bH39cG9bbVw_127);
	}
LA486_: ;
	(*Result).isGroup = NIM_FALSE;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(curIdent_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, langSymbolGroup__packagesZdocutilsZdochelpers_u145)(NimStringV2 kind_p0, NimStringV2 name_p1, tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* Result) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw));
	{
		NIM_BOOL T3_;
		tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T6_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_128, 7, kind_p0);
		if (!!(T3_)) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
		(*T6_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
		(*T6_).Sup.Sup.name = "ValueError";
		T7_[0] = kind_p0;
		(*T6_).Sup.Sup.message = nsuFormatOpenArray(TM__jCyLKAh8jREuI9bH39cG9bbVw_130, T7_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*T6_).Sup.Sup.parent = ((Exception*) NIM_NIL);
		raiseExceptionEx((Exception*)T6_, "ValueError", "langSymbolGroup", "dochelpers.nim", 84);
goto BeforeRet_;
	}
LA4_: ;
	nimZeroMem((void*)Result, sizeof(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw));
	colontmpD_ = eqdup___system_u2697(kind_p0);
	(*Result).symKind = colontmpD_;
	colontmpD__2 = eqdup___system_u2697(name_p1);
	(*Result).name = colontmpD__2;
	(*Result).isGroup = NIM_TRUE;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, match__packagesZdocutilsZdochelpers_u649)(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* generated_p0, tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* docLink_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_TRUE;
	{
		if (!!(((*docLink_p1).symKind.len == 0))) goto LA3_;
		{
			if (!eqStrings((*generated_p0).symKind, TM__jCyLKAh8jREuI9bH39cG9bbVw_131)) goto LA7_;
			result = contains__stdZenumutils_u51(TM__jCyLKAh8jREuI9bH39cG9bbVw_132, 2, (*docLink_p1).symKind);
		}
		goto LA5_;
LA7_: ;
		{
			result = eqStrings((*generated_p0).symKind, (*docLink_p1).symKind);
			{
				NIM_BOOL T12_;
				NIM_BOOL T13_;
				T12_ = (NIM_BOOL)0;
				T13_ = (NIM_BOOL)0;
				T13_ = result;
				if (!(T13_)) goto LA14_;
				T13_ = eqStrings((*docLink_p1).symKind, TM__jCyLKAh8jREuI9bH39cG9bbVw_133);
LA14_: ;
				T12_ = T13_;
				if (!(T12_)) goto LA15_;
				T12_ = !(((*docLink_p1).symTypeKind.len == 0));
LA15_: ;
				if (!T12_) goto LA16_;
				result = eqStrings((*generated_p0).symTypeKind, (*docLink_p1).symTypeKind);
			}
LA16_: ;
		}
LA5_: ;
		{
			if (!!(result)) goto LA20_;
			goto BeforeRet_;
		}
LA20_: ;
	}
LA3_: ;
	result = eqStrings((*generated_p0).name, (*docLink_p1).name);
	{
		if (!!(result)) goto LA24_;
		goto BeforeRet_;
	}
LA24_: ;
	{
		if (!(*generated_p0).isGroup) goto LA28_;
		result = !((*docLink_p1).parametersProvided);
		goto BeforeRet_;
	}
LA28_: ;
	{
		if (!!(((*docLink_p1).generics.len == 0))) goto LA32_;
		result = eqStrings((*generated_p0).generics, (*docLink_p1).generics);
		{
			if (!!(result)) goto LA36_;
			goto BeforeRet_;
		}
LA36_: ;
	}
LA32_: ;
	{
		if (!!(((*docLink_p1).outType.len == 0))) goto LA40_;
		result = eqStrings((*generated_p0).outType, (*docLink_p1).outType);
		{
			if (!!(result)) goto LA44_;
			goto BeforeRet_;
		}
LA44_: ;
	}
LA40_: ;
	{
		NI T50_;
		NI T51_;
		NIM_BOOL onlyType_1;
		if (!(*docLink_p1).parametersProvided) goto LA48_;
		T50_ = (*generated_p0).parameters.len;
		T51_ = (*docLink_p1).parameters.len;
		result = (T50_ == T51_);
		{
			if (!!(result)) goto LA54_;
			goto BeforeRet_;
		}
LA54_: ;
		onlyType_1 = NIM_FALSE;
		{
			NI i_1;
			NI colontmp_;
			NI T57_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T57_ = (*generated_p0).parameters.len;
			colontmp_ = T57_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyTuple__UV3llMMYFckfui8YMBuUZA g_1;
					tyTuple__UV3llMMYFckfui8YMBuUZA d_1;
					if (!(i_2 < colontmp_)) goto LA59;
					nimZeroMem((void*)(&g_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					nimZeroMem((void*)(&d_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					i_1 = i_2;
					eqcopy___stdZprivateZospaths2_u309((&g_1), (*generated_p0).parameters.p->data[i_1]);
					eqcopy___stdZprivateZospaths2_u309((&d_1), (*docLink_p1).parameters.p->data[i_1]);
					{
						if (!(i_1 == ((NI)0))) goto LA63_;
						{
							if (!eqStrings(g_1.Field1, d_1.Field0)) goto LA67_;
							onlyType_1 = NIM_TRUE;
						}
LA67_: ;
					}
LA63_: ;
					{
						if (!onlyType_1) goto LA71_;
						result = eqStrings(g_1.Field1, d_1.Field0);
					}
					goto LA69_;
LA71_: ;
					{
						{
							if (!!((d_1.Field1.len == 0))) goto LA76_;
							result = eqStrings(g_1.Field1, d_1.Field1);
							{
								if (!!(result)) goto LA80_;
								eqdestroy___stdZprivateZospaths2_u306(d_1);
								eqdestroy___stdZprivateZospaths2_u306(g_1);
								goto BeforeRet_;
							}
LA80_: ;
						}
LA76_: ;
						result = eqStrings(g_1.Field0, d_1.Field0);
					}
LA69_: ;
					{
						if (!!(result)) goto LA84_;
						eqdestroy___stdZprivateZospaths2_u306(d_1);
						eqdestroy___stdZprivateZospaths2_u306(g_1);
						goto BeforeRet_;
					}
LA84_: ;
					i_2 += ((NI)1);
					{
						LA60_:;
					}
					{
						eqdestroy___stdZprivateZospaths2_u306(d_1);
						eqdestroy___stdZprivateZospaths2_u306(g_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA59: ;
			}
		}
	}
LA48_: ;
	}BeforeRet_: ;
	return result;
}
